#!/bin/bash

BASEPATH=`pwd`
PACKAGE_ROOT=${BASEPATH}
#LOGFILE="${PACKAGE_ROOT}/maestro-install.log"
LOGFILE="/var/log/maestro-install.log"

BINARY_NAME="15_DSC_IOT_ALS.bin"	

TEMP_PATH="/tmp/fwUpd"

DSC_ID=15

UPDATE_MAJOR=3
UPDATE_MINOR=20
UPDATE_BUILD=0

XML_ENTRY='DSC_IOT_ALS'

ERROR_COUNT=0

EXIT_SUCCESS=0                  # Success
EXIT_FAIL=1                     # Generic Failure
EXIT_PLATFORM_NOT_SUPPORTED=2   # Target platform not supported by install package.
EXIT_INVALID_MSU=3              # MSU is not valid.
EXIT_MISSING_COMPONENT=4        # Component missing from install package.
EXIT_FAIL_RPM=5                 # RPM failed to install.
EXIT_FAIL_FRONTEND=6            # Front-end failed to install.
EXIT_FAIL_DOWNGRADE=7           # Attempt to downgrade the software
EXIT_FAIL_NETWORK=9

function echo()
{
    builtin echo "$@" | tee -a "${LOGFILE}"
}

#echo script version
echo Ares update script v2

#check if the iot board is in app mode or bootloader
#create temp dir
mkdir ${TEMP_PATH}
(/usr/local/bin/fw_listDSC_arm >> ${TEMP_PATH}/listDsc.txt)&
DSCPID=$!
sleep 3
kill $DSCPID

#check for version or mode
APP_VER=$(grep -m 1 "ID: ${DSC_ID}" ${TEMP_PATH}/listDsc.txt | grep -o -E '[0-9]\.[0-9]{1,2}\.[0-9]{1,2}')

#disable echo
TEMPVAR=$LOGFILE
LOGFILE="/dev/null"
APP_MAJOR=$(echo "$APP_VER" | cut -f1 -d.)
APP_MINOR=$(echo "$APP_VER" | cut -f2 -d.)
APP_BUILD=$(echo "$APP_VER" | cut -f3 -d.)
LOGFILE=$TEMPVAR

echo "app version : "$APP_VER
echo "update version : ${UPDATE_MAJOR}.${UPDATE_MINOR}.${UPDATE_BUILD}"

#cast to integer
APP_MAJOR=$(($APP_MAJOR+0))
APP_BUILD=$(($APP_BUILD+0))
APP_MINOR=$(($APP_MINOR+0))

#delete temp file
rm ${TEMP_PATH}/listDsc.txt


if !(($APP_MAJOR == 0 && $APP_MINOR == 0 && $APP_BUILD == 0))
then
	#check for downgrade
	if 	!(( (( $APP_MAJOR < $UPDATE_MAJOR )) || \
		(( $APP_MAJOR == $UPDATE_MAJOR && $APP_MINOR < $UPDATE_MINOR )) || \
		(( $APP_MAJOR == $UPDATE_MAJOR && $APP_MINOR == $UPDATE_MINOR && $APP_BUILD < $UPDATE_BUILD)) ))
	then
		echo "downgrade fail"
		exit $EXIT_FAIL_DOWNGRADE
	else
		echo "update version valid"
	fi
fi

sleep 5



echo updating version in fwver.xml
#update the new version number in xml file
sed -r -i "s/$XML_ENTRY\" Version=\"[0-9]{1,2}\.[0-9]{1,2}\.[0-9]{1,2}\"/$XML_ENTRY\" Version=\"${UPDATE_MAJOR}.${UPDATE_MINOR}.${UPDATE_BUILD}\"/g" /etc/PatientSimulatorConfiguration/conf/fwver.xml

echo "update started"
#start the update process

kill $(pidof MPICMAIN)
kill $(pidof -x eposmotord.sh)
sleep 2

while (( $ERROR_COUNT < 5 ))
do
${PACKAGE_ROOT}/CANupdater ${PACKAGE_ROOT}/${BINARY_NAME} ${DSC_ID} stm32 | tee ${TEMP_PATH}/return.log | tee -a ${LOGFILE}
	if grep -o "error" ${TEMP_PATH}/return.log
	then
		ERROR_COUNT=$((ERROR_COUNT+1))
		echo errorcount : $ERROR_COUNT
	else
		break
	fi
done

if grep -o "update process succesfull" ${TEMP_PATH}/return.log
then
	#reboot
	echo update success , rebooting
	#give enough time to return the update status to the user before rebooting
	( sleep 1 ; reboot ) &
	exit $EXIT_SUCCESS
else
	echo update fail
	exit $EXIT_FAIL
fi

